==> eiffelstudio-16.05.tar: F_code/C8/et394.c <==
/*
 * Code for class ET_FORMAL_PARAMETER_CHECKER2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et394.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_FORMAL_PARAMETER_CHECKER2}.make */
void F931_8291 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	F906_7888(Current);
	tr1 = RTLNSMART(eif_new_type(1873, 0).id);
	tr2 = *(EIF_REFERENCE *)(Current);
	F1874_19025(RTCW(tr1), tr2, ((EIF_INTEGER_32) 1L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_formal_parameters_validity */
void F931_8292 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,loc5);
	RTLR(4,tr1);
	RTLR(5,loc3);
	RTLIU(6);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	loc4 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_3_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		loc2 = *(EIF_INTEGER_32 *)(loc5+ _LNGOFF_3_0_0_0_);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			loc3 = F1757_17478(loc5, loc1);
			F931_8293(Current, loc3);
			loc1++;
		}
	}
	RTAR(Current, loc4);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc4;
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_constraint_validity */
void F931_8293 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13198[Dtype(arg1)-1737])(RTCW(arg1));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12464[Dtype(loc1)-1510])(loc1, Current);
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_class_type_constraint */
void F931_8294 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc7);
	RTLR(1,arg1);
	RTLR(2,loc9);
	RTLR(3,tr1);
	RTLR(4,loc6);
	RTLR(5,Current);
	RTLR(6,loc3);
	RTLR(7,loc4);
	RTLR(8,loc5);
	RTLR(9,tr2);
	RTLR(10,loc10);
	RTLR(11,tr3);
	RTLIU(12);
	
	RTGC;
	loc7 = F1875_19065(RTCW(arg1));
	tb1 = '\0';
	tb2 = F1875_19077(RTCW(loc7));
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(RTCW(loc7) + _REFACS_3_);
		loc9 = tr1;
		tb1 = EIF_TEST(loc9);
	}
	if (tb1) {
		loc6 = *(EIF_REFERENCE *)(RTCW(arg1) + O14368[Dtype(arg1)-1876]);
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(loc6 == NULL)) {
			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13292[Dtype(loc6)-1752])(RTCW(loc6));
			ti4_2 = *(EIF_INTEGER_32 *)(loc9+ _LNGOFF_3_0_0_0_);
			tb1 = (EIF_BOOLEAN)(ti4_1 != ti4_2);
		}
		if (tb1) {
			F916_8042(Current);
		} else {
			loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13292[Dtype(loc6)-1752])(RTCW(loc6));
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13294[Dtype(loc6)-1752])(RTCW(loc6), loc1);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12464[Dtype(loc3)-1510])(RTCW(loc3), Current);
				loc1++;
			}
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13294[Dtype(loc6)-1752])(RTCW(loc6), loc1);
				loc4 = F1757_17478(loc9, loc1);
				loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13198[Dtype(loc4)-1737])(RTCW(loc4));
				if ((EIF_BOOLEAN)(loc5 == NULL)) {
					tr1 = F906_7890(Current);
					loc5 = *(EIF_REFERENCE *)(RTCW(tr1) + O12046[Dtype(tr1)-1495]);
				}
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = *(EIF_REFERENCE *)(Current);
				F1874_19036(RTCW(tr1), arg1, tr2);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = *(EIF_REFERENCE *)(Current);
				loc8 = F1735_17057(RTCW(loc3), loc5, tr1, tr2);
				if ((EIF_BOOLEAN) !loc8) {
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc7)+ _LNGOFF_26_18_0_3_);
					if ((EIF_BOOLEAN)(ti4_1 == loc1)) {
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R14366[Dtype(arg1)-1876])(RTCW(arg1), *(EIF_REFERENCE *)(Current), *(EIF_REFERENCE *)(Current + _REFACS_1_));
						tb1 = '\0';
						tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + O14368[Dtype(arg1)-1876]);
						loc10 = tr1;
						if (EIF_TEST(loc10)) {
							tb1 = (EIF_BOOLEAN)(loc10 != loc6);
						}
						if (tb1) {
							loc6 = (EIF_REFERENCE) loc10;
							loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13294[Dtype(loc6)-1752])(RTCW(loc6), loc1);
							tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
							tr2 = *(EIF_REFERENCE *)(Current);
							loc8 = F1735_17057(RTCW(loc3), loc5, tr1, tr2);
						}
					}
				}
				if ((EIF_BOOLEAN) !loc8) {
					F916_8042(Current);
					tr1 = F906_7892(Current);
					tr2 = *(EIF_REFERENCE *)(Current);
					tr3 = *(EIF_REFERENCE *)(Current);
					F1903_20147(RTCW(tr1), tr2, tr3, arg1, loc3, loc5);
				}
				loc1++;
			}
		}
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_tuple_type_constraint */
void F931_8295 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc3);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13292[Dtype(loc3)-1752])(loc3);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13294[Dtype(loc3)-1752])(loc3, loc1);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12464[Dtype(tr1)-1510])(RTCW(tr1), Current);
			loc1++;
		}
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_class */
void F931_8296 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F931_8297(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_class_type */
void F931_8297 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F931_8294(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_tuple_type */
void F931_8298 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F931_8295(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.constraint_context */
EIF_REFERENCE F931_8299 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit394 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C8/et394.c <==
/*
 * Code for class ET_FORMAL_PARAMETER_CHECKER2
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et394.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_FORMAL_PARAMETER_CHECKER2}.make */
void F976_8700 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTGC;
	F958_8401(Current);
	tr1 = RTLNSMART(eif_new_type(1882, 0).id);
	tr2 = *(EIF_REFERENCE *)(Current);
	F1883_19635(RTCW(tr1), tr2, ((EIF_INTEGER_32) 1L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_formal_parameters_validity */
void F976_8701 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,loc5);
	RTLR(4,tr1);
	RTLR(5,loc3);
	RTLIU(6);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	loc4 = *(EIF_REFERENCE *)(Current);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tr1 = *(EIF_REFERENCE *)(Current);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_3_);
	loc5 = tr1;
	if (EIF_TEST(loc5)) {
		loc2 = *(EIF_INTEGER_32 *)(loc5+ _LNGOFF_3_0_0_0_);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			loc3 = F1765_18060(loc5, loc1);
			F976_8702(Current, loc3);
			loc1++;
		}
	}
	RTAR(Current, loc4);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc4;
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_constraint_validity */
void F976_8702 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13710[Dtype(arg1)-1745])(RTCW(arg1));
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12961[Dtype(loc1)-1512])(loc1, Current);
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_class_type_constraint */
void F976_8703 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(12);
	RTLR(0,loc7);
	RTLR(1,arg1);
	RTLR(2,loc9);
	RTLR(3,tr1);
	RTLR(4,Current);
	RTLR(5,loc6);
	RTLR(6,loc3);
	RTLR(7,loc4);
	RTLR(8,loc5);
	RTLR(9,tr2);
	RTLR(10,loc10);
	RTLR(11,tr3);
	RTLIU(12);
	
	RTGC;
	loc7 = F1884_19675(RTCW(arg1));
	tb1 = '\0';
	tb2 = F1884_19687(RTCW(loc7));
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(RTCW(loc7) + _REFACS_3_);
		loc9 = tr1;
		tb1 = EIF_TEST(loc9);
	}
	if (tb1) {
		tr1 = F958_8403(Current);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R14905[Dtype(arg1)-1885])(RTCW(arg1), tr1);
		loc6 = *(EIF_REFERENCE *)(RTCW(arg1) + O14908[Dtype(arg1)-1885]);
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(loc6 == NULL)) {
			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13804[Dtype(loc6)-1760])(RTCW(loc6));
			ti4_2 = *(EIF_INTEGER_32 *)(loc9+ _LNGOFF_3_0_0_0_);
			tb1 = (EIF_BOOLEAN)(ti4_1 != ti4_2);
		}
		if (tb1) {
			F968_8557(Current);
		} else {
			loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13804[Dtype(loc6)-1760])(RTCW(loc6));
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13806[Dtype(loc6)-1760])(RTCW(loc6), loc1);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12961[Dtype(loc3)-1512])(RTCW(loc3), Current);
				loc1++;
			}
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) (loc1 > loc2)) break;
				loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13806[Dtype(loc6)-1760])(RTCW(loc6), loc1);
				loc4 = F1765_18060(loc9, loc1);
				loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13710[Dtype(loc4)-1745])(RTCW(loc4));
				if ((EIF_BOOLEAN)(loc5 == NULL)) {
					tr1 = F958_8403(Current);
					loc5 = *(EIF_REFERENCE *)(RTCW(tr1) + O12538[Dtype(tr1)-1497]);
				}
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = *(EIF_REFERENCE *)(Current);
				F1883_19646(RTCW(tr1), arg1, tr2);
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
				tr2 = *(EIF_REFERENCE *)(Current);
				loc8 = F1743_17633(RTCW(loc3), loc5, tr1, tr2);
				if ((EIF_BOOLEAN) !loc8) {
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc7)+ _LNGOFF_27_18_0_3_);
					if ((EIF_BOOLEAN)(ti4_1 == loc1)) {
						(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R14906[Dtype(arg1)-1885])(RTCW(arg1), *(EIF_REFERENCE *)(Current), *(EIF_REFERENCE *)(Current + _REFACS_1_));
						tb1 = '\0';
						tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + O14908[Dtype(arg1)-1885]);
						loc10 = tr1;
						if (EIF_TEST(loc10)) {
							tb1 = (EIF_BOOLEAN)(loc10 != loc6);
						}
						if (tb1) {
							loc6 = (EIF_REFERENCE) loc10;
							loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13806[Dtype(loc6)-1760])(RTCW(loc6), loc1);
							tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
							tr2 = *(EIF_REFERENCE *)(Current);
							loc8 = F1743_17633(RTCW(loc3), loc5, tr1, tr2);
						}
					}
				}
				if ((EIF_BOOLEAN) !loc8) {
					F968_8557(Current);
					tr1 = F958_8406(Current);
					tr2 = *(EIF_REFERENCE *)(Current);
					tr3 = *(EIF_REFERENCE *)(Current);
					F1912_20769(RTCW(tr1), tr2, tr3, arg1, loc3, loc5);
				}
				loc1++;
			}
		}
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.check_tuple_type_constraint */
void F976_8704 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc3);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13804[Dtype(loc3)-1760])(loc3);
		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > loc2)) break;
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R13806[Dtype(loc3)-1760])(loc3, loc1);
			(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R12961[Dtype(tr1)-1512])(RTCW(tr1), Current);
			loc1++;
		}
	}
	RTLE;
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_class */
void F976_8705 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F976_8706(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_class_type */
void F976_8706 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F976_8703(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.process_tuple_type */
void F976_8707 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	F976_8704(Current, arg1);
}

/* {ET_FORMAL_PARAMETER_CHECKER2}.constraint_context */
EIF_REFERENCE F976_8708 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit394 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
